fz_buffer_extract

Function fz_buffer_extract 

pub unsafe extern "C" fn fz_buffer_extract(
    ctx: *mut fz_context,
    buf: *mut fz_buffer,
    data: *mut *mut c_uchar,
) -> usize
Take ownership of buffer contents.

Performs the same task as fz_buffer_storage, but ownership of
the data buffer returns with this call. The buffer is left
empty.

Note: Bad things may happen if this is called on a buffer with
multiple references that is being used from multiple threads.

data: Pointer to place to retrieve data pointer.

Returns length of stream.