pub unsafe extern "C" fn fz_debug_store(
ctx: *mut fz_context,
out: *mut fz_output,
)Expand description
Output debugging information for the current state of the store
to the given output channel.
pub unsafe extern "C" fn fz_debug_store(
ctx: *mut fz_context,
out: *mut fz_output,
)Output debugging information for the current state of the store
to the given output channel.