pub unsafe extern "C" fn fz_load_user_css(
ctx: *mut fz_context,
filename: *const c_char,
)Expand description
Set the user stylesheet by loading the source from a file.
If the file is missing, do nothing.
pub unsafe extern "C" fn fz_load_user_css(
ctx: *mut fz_context,
filename: *const c_char,
)Set the user stylesheet by loading the source from a file.
If the file is missing, do nothing.