fz_run_document_structure

Function fz_run_document_structure 

pub unsafe extern "C" fn fz_run_document_structure(
    ctx: *mut fz_context,
    doc: *mut fz_document,
    dev: *mut fz_device,
    cookie: *mut fz_cookie,
)
Run the document structure through a device.

doc: Document in question.

dev: Device obtained from fz_new_*_device.

cookie: Communication mechanism between caller and library.
Intended for multi-threaded applications, while
single-threaded applications set cookie to NULL. The
caller may abort an ongoing rendering of a page. Cookie also
communicates progress information back to the caller. The
fields inside cookie are continually updated while the page is
rendering.