pub unsafe extern "C" fn fz_set_user_css(
ctx: *mut fz_context,
text: *const c_char,
)Expand description
Set the user stylesheet source text for use with HTML and EPUB.
pub unsafe extern "C" fn fz_set_user_css(
ctx: *mut fz_context,
text: *const c_char,
)Set the user stylesheet source text for use with HTML and EPUB.