#[repr(C)]pub struct fz_stext_page {
pub refs: c_int,
pub pool: *mut fz_pool,
pub mediabox: fz_rect,
pub first_block: *mut fz_stext_block,
pub last_block: *mut fz_stext_block,
pub last_struct: *mut fz_stext_struct,
pub id_list: *mut fz_pool_array,
}Expand description
A text page is a list of blocks, together with an overall
bounding box.
The name of this structure is now slightly out of date. It
should really be [fz_stext_document], cos it can contain
content from multiple pages.
Fields
refs: c_intpool: *mut fz_poolmediabox: fz_rectfirst_block: *mut fz_stext_blocklast_block: *mut fz_stext_blocklast_struct: *mut fz_stext_structid_list: *mut fz_pool_arrayTrait Implementations
Sourceimpl Clone for fz_stext_page
impl Clone for fz_stext_page
Sourcefn clone(&self) -> fz_stext_page
fn clone(&self) -> fz_stext_page
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for fz_stext_page